[−][src]Struct winapi_util::console::ScreenBufferInfo
Represents console screen buffer information such as size, cursor position and styling attributes.
This wraps a CONSOLE_SCREEN_BUFFER_INFO.
Methods
impl ScreenBufferInfo[src]
pub fn size(&self) -> (i16, i16)[src]
Returns the size of the console screen buffer, in character columns and rows.
This corresponds to dwSize.
pub fn cursor_position(&self) -> (i16, i16)[src]
Returns the position of the cursor in terms of column and row coordinates of the console screen buffer.
This corresponds to dwCursorPosition.
pub fn attributes(&self) -> u16[src]
Returns the character attributes associated with this console.
This corresponds to wAttributes.
See char info for more details.
pub fn max_window_size(&self) -> (i16, i16)[src]
Returns the maximum size of the console window, in character columns and rows, given the current screen buffer size and font and the screen size.
pub fn window_rect(&self) -> SmallRect[src]
Returns the console screen buffer coordinates of the upper-left and lower-right corners of the display window.
This corresponds to srWindow.